@@ -4,7 +4,6 @@ Telephone::Mnemonic::US::Words - Maps US telephone numbers from mnemonic 'easy-t
 can also attempts the reverse and maps telephone digits to mnemonic words.
 
 =cut
-
 package Telephone::Mnemonic::US::Words;
 
 #use 5.012001;
@@ -12,17 +11,49 @@ use strict;
 use warnings;
 use Data::Dumper;
 use Tie::DictFile;
-use Moose::Role;
 use strict;
 use warnings;
-#use Telephone::Mnemonic::US::Math qw/ str_pairs dict_path find_valids /;
-#use Telephone::Mnemonic::US::Number qw/ to_tel_digits to_digits beautify/;
+use Telephone::Mnemonic::US::Number qw/ to_digits /;
+use Telephone::Mnemonic::US::Math qw/ str_pairs dict_path find_valids /;
 #use Scalar::Util 'looks_like_number';
 #use List::Util qw/ first /;
 
 use 5.010000;
-our $VERSION = '0.01';
+our $VERSION = '0.07';
+use Moose::Role;
+requires 'num';
 
+#has pairs    => (is=>'rw', isa=>'ArrayRef', lazy=>1, default=>sub{[]} );
+
+has result   => (is=>'rw');
+has dict     => (is=>'rw', isa=>'HashRef', builder=>'dict_io', lazy=>0, predicate=>'dict_p');
+has timeout  => (is=>'rw', isa=>'Num', default=>0);
+
+sub dict_io {
+    my %hash;
+    $Tie::DictFile::MAX_WORD_LENGTH = 14;
+    tie %hash, 'Tie::DictFile', dict_path || return;
+	shift->dict( \%hash );
+}
+
+
+sub to_words {
+    my $self = shift;
+	# Error Checking...
+    # TODO: Dict works?
+	return unless $self->dict_p ;
+    #my $num = to_tel_digits($num) || die "Not a US phone number. Aborting...\n";
+    my $num   = to_digits($self->without_area_code) ;
+	return if $num =~ /[0-1]/o  ;
+    my $pairs = str_pairs($num);
+    my $res   = find_valids ($pairs, $self->dict, $self->timeout);
+    # sort by max segment
+    $res = [sort { $a->{max_seg} < $b->{max_seg} }  @$res];
+	$self->result($res) ;
+}
+
+1;
+__END__
 
 =pod
 
